import request from "@/utils/request";

let url = '/jianYanJianChaShenQing/'

export function huoQuJianChaShenQing(data) {
    return request({
        url: url + 'huoQuJianChaShenQing',
        method: 'post',
        data
    })
}

export function huoQuJianYanJianChaMing(name, patNo, times, bedNo, reqType) {
    return request({
        url: url + 'huoQuJianYanJianChaMing',
        method: 'get',
        params: {name, patNo, times, bedNo, reqType}
    })
}

export function getCheckNewApplication() {
    return request({
        url: url + 'getCheckNewApplication',
        method: 'get',
    })
}


export function jianChaJianYanFenLei(total, currentPage, leiXing, jianCha) {
    return request({
        url: url + 'jianChaJianYanFenLei',
        method: 'get',
        params: {total, currentPage, leiXing, jianCha}
    })
}

export function huoQuShengQingXiangQing(reqNo) {
    return request({
        url: url + 'huoQuShengQingXiangQing',
        method: 'get',
        params: {reqNo}
    })
}

export function queryCheckTextResults(patNo, reqNo) {
    return request({
        url: url + 'queryCheckTextResults',
        method: 'get',
        params: {patNo, reqNo}
    })
}

export function huoMuShuoMingMuBan(name, fenLei, total, currentPage) {
    return request({
        url: url + 'huoMuShuoMingMuBan',
        method: 'get',
        params: {name, fenLei, total, currentPage}
    })
}

export function shouMingMuBanChaoZuo(data) {
    return request({
        url: url + 'shouMingMuBanChaoZuo',
        method: 'post',
        data
    })
}

export function diagnosisInOurHospital(name) {
    return request({
        url: url + 'diagnosisInOurHospital',
        method: 'get',
        params: {name}
    })
}

export function getTemplate(itemType, templateType) {
    return request({
        url: url + 'getTemplate',
        method: 'get',
        params: {itemType, templateType}
    })
}

export function shanShuJianChaMuBan(code, deptCode) {
    return request({
        url: url + 'shanShuJianChaMuBan',
        method: 'get',
        params: {code, deptCode}
    })
}

export function jianChaJianYanMuBanMing(name, reqType) {
    return request({
        url: url + 'jianChaJianYanMuBanMing',
        method: 'get',
        params: {name, reqType}
    })
}

export function baoCunJianChaJianYanMuBan(data) {
    return request({
        url: url + 'baoCunJianChaJianYanMuBan',
        method: 'post',
        data
    })
}

export function baoCunJianYanJianCha(data) {
    return request({
        url: url + 'baoCunJianYanJianCha',
        method: 'post',
        data
    })
}

/* ------------------------- 下面是检验的逻辑 --------------*/

export function huoQuJianYan(data) {
    return request({
        url: url + 'huoQuJianYan',
        method: 'post',
        data
    })
}

export function biaoBenApi(name) {
    return request({
        url: url + 'biaoBenShuJu',
        method: 'get',
        params: {name}
    })
}


export function viewInspectionItemDetails(orderCode) {
    return request({
        url: url + 'viewInspectionItemDetails',
        method: 'get',
        params: {orderCode}
    })
}

export function shanChuJianChaJianYan(reqNo, patNo, times) {
    return request({
        url: url + 'shanChuJianChaJianYan',
        method: 'get',
        params: {reqNo, patNo, times}
    })
}

// 获取检验检查树状图
export function getJyJcZdTree() {
    return request({
        url: url + 'getJyJcZdTree',
        method: 'get',
    })
}

export function getJcItem(code) {
    return request({
        url: url + 'getJcItem',
        method: 'get',
        params: {code}
    })
}

export function getJyItem(code) {
    return request({
        url: url + 'getJyItem',
        method: 'get',
        params: {code}
    })
}

















